/**
 * Copyright 1998-2007, CHISEL Group, University of Victoria, Victoria, BC, Canada.
 * All rights reserved.
 */
package ca.uvic.csr.shrimp.gui.QueryView;


/**
 * Holds the result of a query.  Indicates if the query was cancelled, or if an error occurred.
 * If the query completed successfully then the number of matching nodes as well as the arcs and neighbours are saved. 
 * 
 * @author Chris Callendar
 * @date 6-Dec-06
 */
public class QueryResult {

	private int nodes;
	private int arcs;
	private int neighbors;
	private boolean error;
	private String message;
	private boolean cancelled;
	
	public QueryResult() {
		nodes = 0;
		arcs = 0;
		neighbors = 0;
		error = false;
		message = "";
		cancelled = false;
	}
	
	public boolean hasResults() {
		return (nodes > 0);
	}
	
	public String toString() {
		if (isCancelled()) {
			return "Query cancelled ";
		} else if (isError()) {
			return getMessage();
		} else if (hasResults()) {
			return "Found " + nodes + (nodes == 1 ? " node and " : " nodes and ") + 
				arcs + (arcs == 1 ? " arc " : " arcs ");
		}
		return "Sorry, no matching nodes found ";
	}

	public int getArcs() {
		return arcs;
	}
	
	public void setArcs(int arcs) {
		this.arcs = arcs;
	}
		
	public boolean isError() {
		return error;
	}
	
	public void setError(boolean error) {
		this.error = error;
	}
	
	public int getNodes() {
		return nodes;
	}
	
	public void setNodes(int matchingNodes) {
		this.nodes = matchingNodes;
	}

	public String getMessage() {
		return message;
	}
	
	public void setMessage(String message) {
		this.message = message;
	}

	public int getNeighbors() {
		return neighbors;
	}

	public void setNeighbors(int neighbors) {
		this.neighbors = neighbors;
	}

	
	public boolean isCancelled() {
		return cancelled;
	}

	
	public void setCancelled(boolean cancelled) {
		this.cancelled = cancelled;
	}
	
}
